==> cf-report-image-toolbox-1.0.7.tgz: package/src/image-enricher-jira-info/index.ts <==
import _ from 'lodash'
import chalk from 'chalk'

import { JiraEnricherInputs, LinkCallback } from './types'
import { JiraService } from '../api/jira/jira.service'
import { CodefreshAPI } from '../api/codefresh'
import { Platform } from '../image-enricher-git-info/types'

export async function imageEnricherJiraInfo(inputs: JiraEnricherInputs, linkCallback?: LinkCallback) {
  console.log('starting jira enricher library')

  console.log(`looking for Issues from message ${inputs.message}`)

  const jiraService = new JiraService(inputs)
  try {
    await jiraService.init()
  } catch (error) {
    throw new Error(`Cant initialize jira client, reason: ${error.message}`)
  }

  const issues = jiraService.extract()

  if (!_.isArray(issues)) {
    if (inputs.failOnNotFound === 'true') {
      throw new Error(`issues weren't found, FAIL_ON_NOT_FOUND=true`)
    }
    console.warn(`issues weren't found, FAIL_ON_NOT_FOUND=false`)
    return
  } else {
    console.log(`detected issues: [${issues!.join(', ')}]`)
  }

  for (const issue of issues!) {
    const normalizedIssue = issue.toUpperCase()
    console.log(`looking for the issue ${normalizedIssue}`)

    const issueInfo = await jiraService.getInfoAboutIssue(normalizedIssue)
      .catch((error) => console.error(`Can't find jira ticket with number "${normalizedIssue}".\n${error.message}`))
    if (!issueInfo) {
      // issue not found and error not thrown, continue execution
      continue
    }

    const baseUrl = issueInfo.baseUrl || inputs.jira?.host
    const url = `${baseUrl}/browse/${normalizedIssue}`
    const avatarUrls = _.get(issueInfo, 'fields.assignee.avatarUrls', {})

    if (linkCallback) {
      await linkCallback(url)
    }

    const codefreshAPI = new CodefreshAPI(inputs.cfHost, inputs.cfApiKey)
    const gitopsImageReportingFeature = await codefreshAPI.getFeature('gitopsImageReporting')

    if (inputs.platform === Platform.CLASSIC) {
      await codefreshAPI.createIssueAnnotationClassic(inputs.imageName, {
        number: normalizedIssue,
        url: url,
        title: _.get(issueInfo, 'fields.summary'),
      })

      console.log(chalk.green(`codefresh assigned issue ${normalizedIssue} to your classic image ${inputs.imageName}`))
    }

    if (inputs.platform === Platform.GITOPS || gitopsImageReportingFeature) {
      await codefreshAPI.createIssueAnnotation(inputs.imageName, {
        number: normalizedIssue,
        url: url,
        title: _.get(issueInfo, 'fields.summary'),
        assignee: _.get(issueInfo, 'fields.assignee.displayName'),
        status: _.get(issueInfo, 'fields.status.name'),
        avatarURL: Object.values(avatarUrls)[0]
      })

      console.log(chalk.green(`codefresh assigned issue ${normalizedIssue} to your gitops image ${inputs.imageName}`))
    }
  }

}

==> cf-report-image-toolbox-1.0.14.tgz: package/src/image-enricher-jira-info/index.ts <==
import _ from 'lodash'
import chalk from 'chalk'

import { JiraEnricherInputs, LinkCallback } from './types'
import { JiraService } from '../api/jira/jira.service'
import { CodefreshAPI } from '../api/codefresh'
import { Platform } from '../image-enricher-git-info/types'

export async function imageEnricherJiraInfo(inputs: JiraEnricherInputs, linkCallback?: LinkCallback) {
  console.log('starting jira enricher library')

  console.log(`looking for Issues from message ${inputs.message}`)

  const jiraService = new JiraService(inputs)
  try {
    await jiraService.init()
  } catch (error) {
    throw new Error(`Cant initialize jira client, reason: ${error.message}`)
  }

  const issues = jiraService.extract()

  if (!_.isArray(issues)) {
    if (inputs.failOnNotFound === 'true') {
      throw new Error(`issues weren't found, FAIL_ON_NOT_FOUND=true`)
    }
    console.warn(`issues weren't found, FAIL_ON_NOT_FOUND=false`)
    return
  } else {
    console.log(`detected issues: [${issues.join(', ')}]`)
  }

  for (const issue of issues) {
    const normalizedIssue = issue.toUpperCase()
    console.log(`looking for the issue ${normalizedIssue}`)

    const issueInfo = await jiraService.getInfoAboutIssue(normalizedIssue)
      .catch((error) => console.error(`Can't find jira ticket with number "${normalizedIssue}".\n${error.message}`))
    if (!issueInfo) {
      // issue not found and error not thrown, continue execution
      continue
    }

    const baseUrl = issueInfo.baseUrl || inputs.jira?.host
    const url = `${baseUrl}/browse/${normalizedIssue}`
    const avatarUrls = _.get(issueInfo, 'fields.assignee.avatarUrls', {})

    if (linkCallback) {
      await linkCallback(url)
    }

    const codefreshAPI = new CodefreshAPI(inputs.cfHost, inputs.cfApiKey)
    const gitopsImageReportingFeature = await codefreshAPI.getFeature('gitopsImageReporting')

    if (inputs.platform === Platform.CLASSIC) {
      await codefreshAPI.createIssueAnnotationClassic(inputs.imageName, {
        number: normalizedIssue,
        url: url,
        title: _.get(issueInfo, 'fields.summary'),
      })

      console.log(chalk.green(`codefresh assigned issue ${normalizedIssue} to your classic image ${inputs.imageName}`))
    }

    if (inputs.platform === Platform.GITOPS || gitopsImageReportingFeature) {
      await codefreshAPI.createIssueAnnotation(inputs.imageName, {
        number: normalizedIssue,
        url: url,
        title: _.get(issueInfo, 'fields.summary'),
        assignee: _.get(issueInfo, 'fields.assignee.displayName'),
        status: _.get(issueInfo, 'fields.status.name'),
        avatarURL: Object.values(avatarUrls)[0]
      })

      console.log(chalk.green(`codefresh assigned issue ${normalizedIssue} to your gitops image ${inputs.imageName}`))
    }
  }

}
